@@ -9,7 +9,7 @@ import uuid
 class Entity(Base, SerializerMixin):
 
     __abstract__  = True
-    serialize_only =('date_created','date_modified', 'name', 'description')
+    serialize_rules =('-id', "-uuid")
     
     id = Column(Integer, primary_key=True)
     uuid = Column(UUIDType(binary=False), unique=True, nullable=False, default=uuid.uuid4)
